Enum BM25Error

pub enum BM25Error {
    Generic {
        name: String,
        source: Box<dyn Error + Send + Sync>,
    },
    Serialization {
        name: String,
        source: Box<dyn Error + Send + Sync>,
    },
    NotFound {
        name: String,
        token: String,
    },
    AlreadyExists {
        name: String,
        id: u64,
    },
    TokenizeFailed {
        name: String,
        id: u64,
        text: String,
    },
}
Errors that can occur when working with BM25 index.

Variants



Generic

Index-related errors.

Fields

name: String
source: Box<dyn Error + Send + Sync>


Serialization

CBOR serialization/deserialization errors

Fields

name: String
source: Box<dyn Error + Send + Sync>


NotFound

Error when a token is not found.

Fields

name: String
token: String


AlreadyExists

Error when trying to add a segment with an ID that already exists

Fields

name: String
id: u64


TokenizeFailed

Error when tokenization produces no tokens for a segment

Fields

name: String
id: u64
text: String