pub struct FieldEntry { /* private fields */ }Expand description
Field entry definition for Anda DB
Contains field name, type, constraints, and index information Field names are renamed in serialization to save storage space
Implementations
Sourceimpl FieldEntry
impl FieldEntry
Sourcepub fn new(name: String, type: FieldType) -> Result<FieldEntry, SchemaError>
pub fn new(name: String, type: FieldType) -> Result<FieldEntry, SchemaError>
Sourcepub fn with_description(self, description: String) -> FieldEntry
pub fn with_description(self, description: String) -> FieldEntry
Sourcepub fn with_unique(self) -> FieldEntry
pub fn with_unique(self) -> FieldEntry
Sourcepub fn with_idx(self, idx: usize) -> FieldEntry
pub fn with_idx(self, idx: usize) -> FieldEntry
pub fn required(&self) -> bool
Sourcepub fn extract(
&self,
val: Value,
validate: bool,
) -> Result<FieldValue, SchemaError>
pub fn extract( &self, val: Value, validate: bool, ) -> Result<FieldValue, SchemaError>
Sourcepub fn validate(&self, value: &FieldValue) -> Result<(), SchemaError>
pub fn validate(&self, value: &FieldValue) -> Result<(), SchemaError>