pub struct StorageConfig {
pub cache_max_capacity: u64,
pub compress_level: i32,
pub object_chunk_size: usize,
pub max_small_object_size: usize,
pub bucket_overload_size: usize,
}Expand description
Configuration for the object store storage layer.
Fields
cache_max_capacity: u64Maximum number of items in the cache. 0 disables the cache.
compress_level: i32Zstd compression level. 0 disables compression, 1-22 represent compression levels. Default is 3. 22 indicates the highest compression ratio.
object_chunk_size: usizeChunk size for buffered reading/writing, streaming operations and encryption. Cannot changed after initialization.
max_small_object_size: usizeMaximum size (in bytes) for objects considered “small” enough for single put operations and caching.
bucket_overload_size: usizeMaximum size of a index bucket before creating a new one When a bucket’s stored data exceeds this size, a new bucket should be created for new data