pub enum BM25Error {
Generic {
name: String,
source: Box<dyn Error + Send + Sync>,
},
Serialization {
name: String,
source: Box<dyn Error + Send + Sync>,
},
NotFound {
name: String,
token: String,
},
AlreadyExists {
name: String,
id: u64,
},
TokenizeFailed {
name: String,
id: u64,
text: String,
},
}Expand description
Errors that can occur when working with BM25 index.
Variants
Generic
Index-related errors.
Serialization
CBOR serialization/deserialization errors
NotFound
Error when a token is not found.
AlreadyExists
Error when trying to add a segment with an ID that already exists
TokenizeFailed
Error when tokenization produces no tokens for a segment